import sys
from typing import Any

if sys.version_info >= (3,):
    from urllib.parse import quote_from_bytes

    url_quote = quote_from_bytes
else:
    import urllib

    url_quote = urllib.quote

PY2: Any
PYPY: Any
unichr: Any
range_type: Any
text_type: Any
string_types: Any
integer_types: Any
iterkeys: Any
itervalues: Any
iteritems: Any
NativeStringIO: Any

def reraise(tp, value, tb: Any | None = ...): ...

ifilter: Any
imap: Any
izip: Any
intern: Any
implements_iterator: Any
implements_to_string: Any
encode_filename: Any
get_next: Any

def with_metaclass(meta, *bases): ...



from jinja2.bccache import (
    BytecodeCache as BytecodeCache,
    FileSystemBytecodeCache as FileSystemBytecodeCache,
    MemcachedBytecodeCache as MemcachedBytecodeCache,
)
from jinja2.environment import Environment as Environment, Template as Template
from jinja2.exceptions import (
    TemplateAssertionError as TemplateAssertionError,
    TemplateError as TemplateError,
    TemplateNotFound as TemplateNotFound,
    TemplatesNotFound as TemplatesNotFound,
    TemplateSyntaxError as TemplateSyntaxError,
    UndefinedError as UndefinedError,
)
from jinja2.filters import (
    contextfilter as contextfilter,
    environmentfilter as environmentfilter,
    evalcontextfilter as evalcontextfilter,
)
from jinja2.loaders import (
    BaseLoader as BaseLoader,
    ChoiceLoader as ChoiceLoader,
    DictLoader as DictLoader,
    FileSystemLoader as FileSystemLoader,
    FunctionLoader as FunctionLoader,
    ModuleLoader as ModuleLoader,
    PackageLoader as PackageLoader,
    PrefixLoader as PrefixLoader,
)
from jinja2.runtime import (
    DebugUndefined as DebugUndefined,
    StrictUndefined as StrictUndefined,
    Undefined as Undefined,
    make_logging_undefined as make_logging_undefined,
)
from jinja2.utils import (
    Markup as Markup,
    clear_caches as clear_caches,
    contextfunction as contextfunction,
    environmentfunction as environmentfunction,
    escape as escape,
    evalcontextfunction as evalcontextfunction,
    is_undefined as is_undefined,
    select_autoescape as select_autoescape,
)
